@@ -46,6 +46,176 @@ import aws_cdk.custom_resources
 import constructs
 
 
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.AccountProps",
+    jsii_struct_bases=[],
+    name_mapping={"email": "email", "name": "name"},
+)
+class AccountProps:
+    def __init__(self, *, email: builtins.str, name: builtins.str) -> None:
+        '''The properties of an Account.
+
+        :param email: The email address of the account. Most be unique.
+        :param name: The name of the account.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "email": email,
+            "name": name,
+        }
+
+    @builtins.property
+    def email(self) -> builtins.str:
+        '''The email address of the account.
+
+        Most be unique.
+        '''
+        result = self._values.get("email")
+        assert result is not None, "Required property 'email' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''The name of the account.'''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "AccountProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.OUProps",
+    jsii_struct_bases=[],
+    name_mapping={"name": "name"},
+)
+class OUProps:
+    def __init__(self, *, name: builtins.str) -> None:
+        '''The properties of an OU.
+
+        :param name: The name of the OU.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "name": name,
+        }
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        '''The name of the OU.'''
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "OUProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.OrgObject",
+    jsii_struct_bases=[],
+    name_mapping={
+        "children": "children",
+        "properties": "properties",
+        "type": "type",
+        "id": "id",
+    },
+)
+class OrgObject:
+    def __init__(
+        self,
+        *,
+        children: typing.Sequence["OrgObject"],
+        properties: typing.Union[OUProps, AccountProps],
+        type: "OrgObjectTypes",
+        id: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''The structure of an OrgObject.
+
+        :param children: Other org objects that are children of this org object.
+        :param properties: The org object properties.
+        :param type: The type of the org object.
+        :param id: The unique id of the OrgObject. This is used as the unique identifier when instantiating a construct object. This is important for the CDK to be able to maintain a reference for the object when utilizing the processOrgObj function rather then using the name property of an object which could change. If the id changes the CDK treats this as a new construct and will create a new construct resource and destroy the old one. Not strictly required but useful when using the processOrgObj function. If the id is not provided the name property will be used as the id in processOrgObj. You can create a unique id however you like. A bash example is provided.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "children": children,
+            "properties": properties,
+            "type": type,
+        }
+        if id is not None:
+            self._values["id"] = id
+
+    @builtins.property
+    def children(self) -> typing.List["OrgObject"]:
+        '''Other org objects that are children of this org object.'''
+        result = self._values.get("children")
+        assert result is not None, "Required property 'children' is missing"
+        return typing.cast(typing.List["OrgObject"], result)
+
+    @builtins.property
+    def properties(self) -> typing.Union[OUProps, AccountProps]:
+        '''The org object properties.'''
+        result = self._values.get("properties")
+        assert result is not None, "Required property 'properties' is missing"
+        return typing.cast(typing.Union[OUProps, AccountProps], result)
+
+    @builtins.property
+    def type(self) -> "OrgObjectTypes":
+        '''The type of the org object.'''
+        result = self._values.get("type")
+        assert result is not None, "Required property 'type' is missing"
+        return typing.cast("OrgObjectTypes", result)
+
+    @builtins.property
+    def id(self) -> typing.Optional[builtins.str]:
+        '''The unique id of the OrgObject.
+
+        This is used as the unique identifier when instantiating a construct object.
+        This is important for the CDK to be able to maintain a reference for the object when utilizing
+        the processOrgObj function rather then using the name property of an object which could change.
+        If the id changes the CDK treats this as a new construct and will create a new construct resource and
+        destroy the old one.
+
+        Not strictly required but useful when using the processOrgObj function. If the id is not provided
+        the name property will be used as the id in processOrgObj.
+
+        You can create a unique id however you like. A bash example is provided.
+
+        Example::
+
+            # Example automatically generated from non-compiling source. May contain errors.
+            echo "ou-$( echo $RANDOM | md5sum | head -c 8 )"
+        '''
+        result = self._values.get("id")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "OrgObject(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.enum(jsii_type="@renovosolutions/cdk-library-aws-organization.OrgObjectTypes")
 class OrgObjectTypes(enum.Enum):
     '''The supported OrgObject types.'''
@@ -282,6 +452,9 @@ class OrganizationOUProviderProps:
 
 
 __all__ = [
+    "AccountProps",
+    "OUProps",
+    "OrgObject",
     "OrgObjectTypes",
     "OrganizationOU",
     "OrganizationOUProps",
